@@ -477,7 +477,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             // payment related endpoints
             #[derive(Serialize, Deserialize, JsonSchema)]
             pub struct CorrelationIdParam {
-                correlation_id: <super::#context_type_name<'static> as PaymentProcessor>::CorrelationID
+                correlation_id: String
             }
 
             #[endpoint {
@@ -489,7 +489,6 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 path: Path<IdParam>,
                 body: TypedBody<<super::#context_type_name<'_> as PaymentProcessor>::ProcessArgs>,
             ) -> Result<HttpResponseOk<Payment<
-                <super::#context_type_name<'static> as PaymentProcessor>::CorrelationID,
                 <super::#context_type_name<'static> as PaymentProcessor>::PrivateData,
                 <super::#context_type_name<'static> as PaymentProcessor>::PublicData,
                 <super::#context_type_name<'static> as PaymentProcessor>::ProcessArgs
@@ -535,7 +534,6 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 path: Path<CorrelationIdParam>,
                 body: TypedBody<<super::#context_type_name<'_> as PaymentProcessor>::ProcessArgs>,
             ) -> Result<HttpResponseOk<Payment<
-                <super::#context_type_name<'static> as PaymentProcessor>::CorrelationID,
                 <super::#context_type_name<'static> as PaymentProcessor>::PrivateData,
                 <super::#context_type_name<'static> as PaymentProcessor>::PublicData,
                 <super::#context_type_name<'static> as PaymentProcessor>::ProcessArgs
@@ -580,7 +578,6 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
             ) -> Result<HttpResponseOk<Payment<
-                <super::#context_type_name<'static> as PaymentProcessor>::CorrelationID,
                 <super::#context_type_name<'static> as PaymentProcessor>::PrivateData,
                 <super::#context_type_name<'static> as PaymentProcessor>::PublicData,
                 <super::#context_type_name<'static> as PaymentProcessor>::ProcessArgs
